@@ -1,6 +1,6 @@
 /*
 This is a Optical-Character-Recognition program
-Copyright (C) 2000-2007 Joerg Schulenburg
+Copyright (C) 2000-2010 Joerg Schulenburg
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -24,6 +24,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include <string.h>
 #include <ctype.h>   // toupper, tolower
 #include "pgm2asc.h"
+#include "unicode_defs.h" /* JS.Aug2010 PICTURE def */
 #include "gocr.h"
 
 // ----- detect lines ---------------
@@ -39,6 +40,19 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
    m3 <-- baseline
    m4 <-- bottom of hanging letters (gqpy)
 
+  
+  http://en.wikipedia.org/wiki/Cap_height = 0.70em(?) = 3..12..72pt
+   1pt = 0.0139 inch or 0.3528 mm
+   10pt-font at 72dpi = 10 pixel, 10pt at 96 dpi = 13 pixel (13 PPEm)
+    ascender heigh   (top of OAh = round or pointed letters, O=+..3%,A=+..5%)
+    cap high         (top of HI = flat capital letters)
+    median           (top of x,
+                      curved letters like "acemnor" may exceed x-height)
+    baseline         (base of x)
+    descender height (bottom of p)
+    x-heigh = 1ex (mostly 1ex=0.5em)
+    
+  
   performance can be improved by working with a temporary
   list of boxes of the special text line
 
@@ -79,7 +93,7 @@ int detect_lines1(pix * p, int x0, int y0, int dx, int dy)
   for_each_data(&(JOB->res.boxlist)) {
     box2 = (struct box *)list_get_current(&(JOB->res.boxlist));
     if ( box2->c != PICTURE
-      && box2->num_frames>1 && box2->num_frames<3 /* 1 or 2 holes */
+      && box2->num_frames>1 && box2->num_frames<4 /* 1 or 2 holes */
       && box2->y0 >= y0 && box2->y1 <= y0 + dy
       && box2->x0 >= x0 && box2->x1 <= x0 + dx 
       && box2->frame_vol[0]>0
@@ -694,7 +708,7 @@ int detect_rotation_angle(job_t *job){
 int detect_text_lines(pix * pp, int mo) {
 
   if (JOB->cfg.verbose)
-    fprintf(stderr, "# detect.c detect_text_lines (vvv=16 for more info) ");
+    fprintf(stderr, "# detect.c detect_text_lines (vvv=16 for more info)\n");
   if (mo & 4){
     if (JOB->cfg.verbose) fprintf(stderr, "# zoning\n# ... ");
     detect_lines2(pp, 0, 0, pp->x, pp->y, 0);	// later replaced by better algo
