@@ -1,6 +1,6 @@
 /*
 This is a Optical-Character-Recognition program
-Copyright (C) 2000-2009  Joerg Schulenburg
+Copyright (C) 2000-2010  Joerg Schulenburg
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -46,7 +46,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 static void out_version(int v) {
   fprintf(stderr, " Optical Character Recognition --- gocr "
           version_string " " release_string "\n"
-          " Copyright (C) 2001-2009 Joerg Schulenburg  GPG=1024D/53BDFBE3\n"
+          " Copyright (C) 2001-2010 Joerg Schulenburg  GPG=1024D/53BDFBE3\n"
           " released under the GNU General Public License\n");
   /* as recommended, (c) and license should be part of the binary */
   /* no email because of SPAM, see README for contacting the author */
@@ -308,7 +308,7 @@ static int read_picture(job_t *job) {
     readpcx(job->src.fname, &job->src.p, job->cfg.verbose);
   else
     rc=readpgm(job->src.fname, &job->src.p, job->cfg.verbose);
-  return rc; /* 1 for multiple images, 0 else */
+  return rc; /* 1 for multiple images, -1 on error, 0 else */
 }
 
 /* subject of change, we need more output for XML (ToDo) */
@@ -343,12 +343,18 @@ int main(int argn, char *argv[]) {
 
   JOB = &job;
   setvbuf(stdout, (char *) NULL, _IONBF, 0);	/* not buffered */
-  
-  while (multipnm==1) {
 
-    job_init(&job);
+  job_init(&job); /* init cfg and db */
+
+  process_arguments(&job, argn, argv);
   
-    process_arguments(&job, argn, argv);
+  /* load character data base (JS1002: now outside pgm2asc) */
+  if ( job.cfg.mode & 2 ) /* check for db-option flag */
+    load_db(); /* uses readpnm() and would conflict with multi images */
+        
+  while (multipnm==1) { /* multi-image loop */
+
+    job_init_image(&job); /* single image */
 
     mark_start(&job);
 
@@ -365,9 +371,9 @@ int main(int argn, char *argv[]) {
   
     print_output(&job);
 
-    job_free(&job);
-  
+    job_free_image(&job);
+
   }
-  
-  return 0;
+
+  return ((multipnm<0)?multipnm:0); /* -1=255 on error, 0 ok */
 }
