@@ -1,6 +1,6 @@
 /*
 This is a Optical-Character-Recognition program
-Copyright (C) 2000-2006 Joerg Schulenburg
+Copyright (C) 2000-2010 Joerg Schulenburg
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -29,7 +29,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #define __GOCR_H__
 
 #include "pnm.h"
-#include "unicode.h"
+#include "unicode.h"  /* FORMAT definition */
 #include "list.h"
 #include <stddef.h>
 #ifdef HAVE_GETTIMEOFDAY
@@ -178,7 +178,7 @@ typedef struct job_s {
     int only_numbers; /* numbers only; default value: 0 */
     int verbose; /* verbose mode; default value: 0 */ 
                  /* verbose option (see --help) */
-    FORMAT out_format; /* output format; default value: ISO8859_1*/
+    FORMAT out_format; /* output format; default value: ISO8859_1 */
     char *lc; /* debuglist of chars (_ = not recognized chars) */
               /* default value: "_" */
     char *db_path; /* pathname for database; default value: NULL */
@@ -190,10 +190,11 @@ typedef struct job_s {
 } job_t;
 
 /* initialze job structure */
-void job_init(job_t *job);
+void job_init(job_t *job);        /* once for cfg and db */
+void job_init_image(job_t *job);  /* for each of a multiimage */
 
 /* free job structure */
-void job_free(job_t *job);
+void job_free_image(job_t *job); /* for each of a multiimage */
 
 /*FIXME jb: remove JOB; */
 extern job_t *JOB;
