@@ -1,6 +1,6 @@
 /*
 This is a Optical-Character-Recognition program
-Copyright (C) 2000-2009 Joerg Schulenburg
+Copyright (C) 2000-2010 Joerg Schulenburg
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -26,7 +26,8 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include <assert.h>
 #include "pgm2asc.h"
 #include "gocr.h"
-#include "unicode.h"
+#include "unicode.h" /* decode() */
+#include "unicode_defs.h" /* UNKNOWN */
 
 const char *getTextLine (int line) {
   int i;
@@ -169,12 +170,13 @@ void store_boxtree_lines(int mo) {
    */
   median_gap = calc_median_gap(&JOB->res.lines);
   if (median_gap <= 0) {
+    if ( JOB->cfg.verbose&1 )
       fprintf(stderr, "# Warning: non-positive median line gap of %d\n",
               median_gap);
-      median_gap = 8;
-      max_single_space_gap = 12;  /* arbitrary */
+    median_gap = 8;
+    max_single_space_gap = 12;  /* arbitrary */
   } else {
-      max_single_space_gap = median_gap * 7 / 4;
+    max_single_space_gap = median_gap * 7 / 4;
   }
 
   // Will be subtracted as base_indent to avoid negativ indent.
