@@ -1,7 +1,7 @@
 /* ocr-engine numbers only */
 /*
 This is a Optical-Character-Recognition program
-Copyright (C) 2000-2009 Joerg Schulenburg
+Copyright (C) 2000-2010 Joerg Schulenburg
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -32,6 +32,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include "amiga.h"
 #include "pnm.h"
 #include "gocr.h"
+#include "unicode_defs.h"
 
 /* only for debugging and development */
 #define IFV if(JOB->cfg.verbose&4)
@@ -90,6 +91,15 @@ wchar_t ocr0n(ocr0_shared_t *sdata){
       i1=loop(bp,dx-1,dy-1,dx,cs,0,LE);
       i2=loop(bp,dx-1,dy-2,dx,cs,0,LE);
       if (i2-i1 >= dx/4) Break; // ~{  5x7font
+      // i1, i2 unused now
+
+      if (dx<13 && dy<17)  { // oebb_teletext S5 Aug10
+        i1=loop(bp,   0,0,dx,cs,0,RI);
+        i2=loop(bp,   0,1,dx,cs,0,RI);
+        i3=loop(bp,dx-1,0,dx,cs,0,LE);
+        if (i1>i2 && i3>0) ad=98*ad/100;
+      }
+      // i1, i2, i3 unused now
 
       // get the upper and lower hole koords, y around dy/4 ???
       x=5*dx/8;
@@ -105,7 +115,7 @@ wchar_t ocr0n(ocr0_shared_t *sdata){
       x +=loop(bp,dx-1-x,y,dx,cs,1,LE); if(x>dx/2) Break;
       i2 =loop(bp,dx-1-x,y,dx,cs,0,LE); i2=dx-1-(i2+2*x)/2; // lower center x
 
-      MSG( fprintf(stderr,"i1,i3=%d,%d i2=%d (upper+lower center)",i1,i3,i2);)
+      MSG( fprintf(stderr,"i1,i3=%d,%d i2,y=%d,%d (upper+lower center)",i1,i3,i2,y);)
 
       y  =loop(bp,i1,0,dy,cs,0,DO);
       y +=loop(bp,i1,y,dy,cs,1,DO);
@@ -140,13 +150,14 @@ wchar_t ocr0n(ocr0_shared_t *sdata){
       // sS5 \sl z  left upper v-bow ?
       for(x=dx,i=y=dy/4;y<dy/2;y++){
         j=loop(bp,0,y,dx,cs,0,RI); if(j<x) { x=j; i=y; }
-      } y=i;
-      i1=loop(bp,0,   dy/16     ,dx,cs,0,RI);
-      i2=loop(bp,0,(y+dy/16)/2  ,dx,cs,0,RI);
+      } y=i;  /* get smalles left gap and its y position */
+      i1=loop(bp,0,   dy/16     ,dx,cs,0,RI); /* left gap at top */
+      i2=loop(bp,0,(y+dy/16)/2  ,dx,cs,0,RI); /* left gap below top */
       i =loop(bp,0,(y+dy/16)/2+1,dx,cs,0,RI); if( i>i2 ) i2=i;
-      i3=loop(bp,0, y  ,dx,cs,0,RI);
+      i3=loop(bp,0, y  ,dx,cs,0,RI);  /* left gap at y */
       i =loop(bp,0, y-1,dx,cs,0,RI); if( i<i3 ) i3=i;
-      if( 2*i2+1+dx/16 < i1+i3 ) Break;
+      if( 2*i2+  dx/16 < i1+i3 ) ad=99*ad/100; /* 5S oebb_teletext */
+      if( 2*i2+1+dx/16 < i1+i3 ) Break; /* break if bow */
       
       if( dy>=20 && dx<16 ) /* tall S */
       if(  loop(bp,0,   dy/5     ,dx,cs,0,RI)
@@ -204,22 +215,26 @@ wchar_t ocr0n(ocr0_shared_t *sdata){
       if( num_cross(0, dx-1,dy/2,dy/2,bp,cs) != 1 ) Break;
       if( num_cross(0, dx-1,dy-1,dy-1,bp,cs) != 1
        && num_cross(0, dx-1,dy-2,dy-2,bp,cs) != 1 ) Break;
-      /*  5x7  micr      ocr-a
-      
-               ooo        @@@..
-          .$.  ooo        ..@..
-          $@.   oo        ..@..
-          .$.   oo        ..@..
-          .@.  ooooo      ..@.@
-          .$.  ooooo      ..@.@
-          $@$  ooooo      @@@@@
-          
+      /*  5x7  micr      ocr-a   6x10
+
+          3x6  5x7       5x7      ..@@..<-
+                                  .@@@..
+                                  ..@@..
+               ooo        @@@..   ..@@..<
+          .$.  ooo        ..@..   ..@@..
+          $@.   oo        ..@..   ..@@..
+          .$.   oo        ..@..   ..@@..
+          .@.  ooooo      ..@.@   ..@@..
+          .$.  ooooo      ..@.@   ..@@..
+          $@$  ooooo      @@@@@   @@@@@@<-
        */
       i4=0; // human font
-      if( num_cross(0, dx-1,3*dy/4,3*dy/4,bp,cs) != 2 ) { // except ocr-a
-        for( y=1; y<dy/2; y++ ){
-          if( num_cross(0, dx-1, y  , y  ,bp,cs) == 2 ) break;
-        } if (y>=dy/2) ad=98*ad/100;
+      if (num_cross(0, dx-1,3*dy/4,3*dy/4,bp,cs) != 2 ) { // except ocr-a
+        for (y=1; y<dy/2; y++) {
+          if (num_cross(0, dx-1, y  , y  ,bp,cs) == 2 ) break;
+        } if (y>=dy/2) {
+          if (dx>6) ad=98*ad/100;
+          else      ad=99*ad/100; MSG(fprintf(stderr,"ad= %d",ad);) }
         for( i=dy/8,y=7*dy/16;y<dy-1 && i;y++ ){
           if( num_cross(0, dx-1, y  , y  ,bp,cs) != 1 ) i--;
         } if( dy>8 && !i ) Break;
@@ -252,11 +267,13 @@ wchar_t ocr0n(ocr0_shared_t *sdata){
       }
       // upper and lower width
       x =loop(bp,(i1+i2)/2,dy/2,dx,cs,1,RI); i=x; i3=0;
-      for(y=0;y<7*dy/8;y++)
-        if( loop(bp,i1+y*(i2-i1)/dy, y,dx,cs,1,RI)-i > 1+dx/8 ) break;
-      if(y<7*dy/8) ad=98*ad/100; // serif or ocr-a-1 ?
-      if(y<6*dy/8) ad=99*ad/100; /*  MICR E-13B font Jan07 */
-      if(y<4*dy/8) Break;
+      for (y=0;y<7*dy/8;y++)
+        if ( loop(bp,i1+y*(i2-i1)/dy, y,dx,cs,1,RI)-i > 1+dx/8 ) break;
+      if (y<7*dy/8) { ad=98*ad/100; // serif or ocr-a-1 ?
+        MSG(fprintf(stderr,"i12 %d %d ad= %d", i1,i2,ad);) }
+      if (y<6*dy/8) { ad=99*ad/100; /*  MICR E-13B font Jan07 */
+        MSG(fprintf(stderr,"i12 %d %d ad= %d", i1,i2,ad);) }
+      if (y<4*dy/8) Break;
       MSG(fprintf(stderr,"i12 %d %d ad= %d", i1,i2,ad);)
 // out_x(box1); printf(" i12=%d %d\n",i1,i2);
       x =loop(bp,i2,dy-1,dx,cs,1,LE); j=x;
@@ -266,12 +283,15 @@ wchar_t ocr0n(ocr0_shared_t *sdata){
       if(abs(i-j)>1+dx/8) i3|=1;
       if(i3) Break;        
 //       out_x(box1);printf(" 11 i=%d j=%d i2=%d dx=%d\n",i,j,i1,dx);
+      MSG(fprintf(stderr,"ad= %d", ad);)
       // get most left upper point (i,j)
       for(i=dx,j=y=0;y<7*dy/16;y++){
         x =loop(bp,0,y,dx,cs,0,RI); if(x<i) { i=x;j=y; }
       }  
-      if ( i1-i<7*dx/16 ) ad=ad*98/100;
-      if ( i1-i<6*dx/16 ) ad=ad*98/100; // 4*dx/8 => 7*dx/16  MICR E-13B font
+      if ( i1-i<7*dx/16 ) { ad=ad*98/100;
+        MSG(fprintf(stderr,"i1i %d %d ad= %d", i1,i,ad);) }
+      if ( i1-i<6*dx/16 ) { ad=ad*98/100; // 4*dx/8 => 7*dx/16  MICR E-13B font
+        MSG(fprintf(stderr,"i1i %d %d ad= %d", i1,i,ad);) }
       if ( i1-i<4*dx/16 ) Break;
       MSG(fprintf(stderr,"i12 %d %d ad= %d", i1,i2,ad);)
       x =loop(bp,0,dy/2,dx,cs,0,RI); // right distance
@@ -821,20 +841,26 @@ wchar_t ocr0n(ocr0_shared_t *sdata){
       
       /* check if upper left and lower left points are joined directly */
       ld=line_deviation(box1, i1, i2);
-      MSG(fprintf(stderr," i1-i2 %d %d dist= %d/%d",i1,i2,ld,2*sq(1024/4));)
+      MSG(fprintf(stderr,"i1-i2 %d %d dist= %d/%d",i1,i2,ld,2*sq(1024/4));)
       if (ld >2*sq(1024/4)) Break;
       /* check if lower right and upper right points are joined directly */
       ld=line_deviation(box1, i2, i3);
-      MSG(fprintf(stderr," i2-i3 %d %d dist= %d/%d",i2,i3,ld,2*sq(1024/4));)
+      MSG(fprintf(stderr,"i2-i3 %d %d dist= %d/%d",i2,i3,ld,2*sq(1024/4));)
       if (ld >  sq(1024/4)) Break;
       /* check if lower right and upper right points are joined directly */
       ld=line_deviation(box1, i3, i4);
-      MSG(fprintf(stderr," i3-i4 %d %d dist= %d/%d",i3,i4,ld,2*sq(1024/4));)
+      MSG(fprintf(stderr,"i3-i4 %d %d dist= %d/%d",i3,i4,ld,2*sq(1024/4));)
       if (ld >  sq(1024/4)) Break;
       /* check if lower right and upper right points are joined directly */
       ld=line_deviation(box1, i6, i7);
-      MSG(fprintf(stderr," i6-i7 %d %d dist= %d/%d",i6,i7,ld,2*sq(1024/4));)
+      MSG(fprintf(stderr,"i6-i7 %d %d dist= %d/%d",i6,i7,ld,2*sq(1024/4));)
       if (ld >2*sq(1024/4)) Break;
+      
+      // handwritten a i1=(9,0) i5=(21,1)  Aug2010
+      if (sdata->holes.num == 1  // type C and D against italic a, alpha
+       && // expect no distance between 1 and 5
+         box1->frame_vector[i5][0]
+       - box1->frame_vector[i1][0] > dx/4 ) Break;
 
       // 4 exists as gchar and ~gchar
       if(!hchar){ ad=99*ad/100; }
@@ -1391,11 +1417,13 @@ wchar_t ocr0n(ocr0_shared_t *sdata){
       Setac(box1,(wchar_t)'0',ad);
       break;
    } 
-   // --- test 0 with a straight dot in it -------------------
+   // --- test 0 with a dot in it -------------------
    for(ad=100;dx>4 && dy>5;){  /* v0.46+ */
       DBG( char c_ask='0'; )
       if (sdata->holes.num != 1) Break; /* do not be tolerant */
-      if (sdata->box1->num_frames != 2) ad=85*ad/100;
+      // 8x10 font 2-pixel line width has 3 frames
+      if (sdata->box1->num_frames != 3) ad=85*ad/100; // 2010-09-24
+      // MSG(fprintf(stderr,"ad=%d",ad);)
       if( get_bw(x0      , x0+dx/2,y0+dy/2 , y0+dy/2,box1->p,cs,1) != 1 ) Break;
       if( get_bw(x1-dx/2 , x1     ,y0+dy/2 , y0+dy/2,box1->p,cs,1) != 1 ) Break;
       if( get_bw(x0+dx/2 , x0+dx/2,y1-dy/2 , y1,box1->p,cs,1) != 1 ) Break;
@@ -1412,6 +1440,7 @@ wchar_t ocr0n(ocr0_shared_t *sdata){
       if( num_cross(x1     ,x1     ,y0+dy/3 , y1-dy/3,box1->p,cs)  != 1 )
       if( num_cross(x1-1   ,x1-1   ,y0+dy/3 , y1-dy/3,box1->p,cs)  != 1 ) Break;
       // if( num_hole(x0,x1,y0,y1,box1->p,cs,NULL) != 2 ) Break;
+      // MSG(fprintf(stderr,"ad=%d",ad);)
       
       if( loop(bp,0   ,        0,x1-x0,cs,0,RI)<=
           loop(bp,0   ,  2+dy/32,x1-x0,cs,0,RI)  ) Break;
@@ -1434,7 +1463,8 @@ wchar_t ocr0n(ocr0_shared_t *sdata){
       
       /* test for straight line */
       y =loop(bp,dx/2,dy-1  ,y1-y0,cs,0,UP); if(y>dy/4) Break;
-      y+=loop(bp,dx/2,dy-1-y,y1-y0,cs,1,UP); if(y>dy/3) Break; if (y>dy/4) ad=ad*99/100;
+      y+=loop(bp,dx/2,dy-1-y,y1-y0,cs,1,UP); if(y>dy/3) Break;
+        if (y>dy/4) { ad=ad*99/100;MSG(fprintf(stderr,"ad=%d",ad);) }
       y+=loop(bp,dx/2,dy-1-y,y1-y0,cs,0,UP); if(3*y>2*dy) Break;
       x =loop(bp,dx/2,dy-y,dx/2,cs,0,RI);    if(x==0) Break;
       // MM; fprintf(stderr," y=%d x=%d\n",y-1,x);
@@ -1461,13 +1491,15 @@ wchar_t ocr0n(ocr0_shared_t *sdata){
 
       /* 5x9 font "9" is like "0" */
       if (dx<16)
-      if ( num_cross(x0,x0,y0,y1,box1->p,cs)  != 1 ) ad=98*ad/100;
+      if (num_cross(x0,x0,y0,y1,box1->p,cs)  != 1) {
+        ad=98*ad/100;MSG(fprintf(stderr,"ad=%d",ad);) }
 
        // italic a
       for(i=0,y=6*dy/8;y<dy-dy/16;y++)
-      if( num_cross(0,dx-1,y,y,bp,cs) > 2 ) i++; else i--;
-      if(i>0) ad=ad*98/100; // ~'a' \it a
-      if( !hchar ) ad=90*ad/100;
+        if (num_cross(0,dx-1,y,y,bp,cs) > 2) i++; else i--;
+      if (i>0) { ad=ad*98/100; MSG(fprintf(stderr,"i=%d ad=%d",i,ad);) }
+
+      if (!hchar) ad=90*ad/100;
       Setac(box1,(wchar_t)'0',ad);
       break;
    } 
