@@ -1,6 +1,6 @@
 /*
 This is a Optical-Character-Recognition program
-Copyright (C) 2000-2009  Joerg Schulenburg
+Copyright (C) 2000-2010  Joerg Schulenburg
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -247,10 +247,11 @@ thresholding (unsigned char *image, int rows, int cols,
   int gmin=255,gmax=0;
   int nmin=255,nmax=0;
 
+  // Aug10: i=y0+1, why 1 pixel frame? bug if v[y0] > gmax, fixed
   // calculate min/max (twice?)
-  for (i = y0 + 1; i < y0 + dy - 1; i++) {
+  for (i = y0 /*+ 1*/; i < y0 + dy /*- 1*/; i++) {
     np = &image[i*cols+x0+1];
-    for (j = x0 + 1; j < x0 + dx - 1; j++) {
+    for (j = x0 /*+ 1*/; j < x0 + dx /*- 1*/; j++) {
       if(*np > gmax) gmax=*np;
       if(*np < gmin) gmin=*np;
       np++; /* next pixel */
@@ -271,6 +272,9 @@ thresholding (unsigned char *image, int rows, int cols,
   for (i = y0; i < y0+dy; i++) {
     np = &image[i*cols+x0];
     for (j = x0; j < x0+dx; j++) {
+      if ( *np > gmax || *np <gmin) // should never happen
+        fprintf(stderr,"ERROR th yx= %2d %2d t= %d v= %3d min/max= %d %d\n",
+          i,j,thresholdValue,*np,gmin,gmax);
       *np = (unsigned char) (*np >= thresholdValue || thresholdValue == gmin ?
          (255-(gmax - *np)* 80/(gmax - thresholdValue + 1)) :
          (  0+(*np - gmin)*150/(thresholdValue - gmin    )) );
