@@ -1,6 +1,6 @@
 /*
 This is a Optical-Character-Recognition program
-Copyright (C) 2000-2009  Joerg Schulenburg
+Copyright (C) 2000-2010  Joerg Schulenburg
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -24,6 +24,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include "output.h"
 #include "pcx.h"
 #include "gocr.h"  /* extern job_t JOB; */
+#include "unicode_defs.h" /* UNKNOWN + PICTURE */
 
 /* function is only for debugging and for developing
    it prints out a part of pixmap b at point x0,y0 to stderr
@@ -55,6 +56,7 @@ void out_b(struct box *px, pix *b, int x0, int y0, int dx, int dy, int cs ){
       int i,j,jo;
       fprintf(stderr,"\n#  frames= %d (sumvects=%d)",px->num_frames,
          ((px->num_frames)?px->num_frame_vectors[px->num_frames-1]:-1));
+      // output objects: volume periphery(de:Umfang) num_frame_vectors
       for (jo=j=i=0; i<px->num_frames; i++, jo=j) {
         fprintf(stderr,"\n#  frame %d (%+4d,%3d,%2d) ",
                 i, px->frame_vol[i], px->frame_per[i],
@@ -208,7 +210,7 @@ int debug_img(char *fname, struct job_s *job, int opt) {
   int x, y, ic, dx, i, j, col;
   unsigned char *np;
   pix *pp = &job->tmp.ppo;
-  
+
   if ( opt & 8 ) {		/* clear debug bits in image */
     for(y=0;y<pp->y;y++) {
       np=&pp->p[(pp->x)*y];
@@ -283,7 +285,7 @@ int debug_img(char *fname, struct job_s *job, int opt) {
   }
 
   if (job->cfg.verbose&1)
-    fprintf(stderr,"# writing %s.ppm\n", fname);
+    fprintf(stderr,"# writing %s[.png] xy= %d %d\n", fname, pp->x, pp->y);
   writeppm(fname, pp);
   return 0;
 }
