@@ -1,6 +1,6 @@
 /*
 This is a Optical-Character-Recognition program
-Copyright (C) 2000-2006 Joerg Schulenburg
+Copyright (C) 2000-2010 Joerg Schulenburg
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -26,7 +26,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include "pnm.h"
 #include "output.h"
 #include "list.h"
-#include "unicode.h"
+/* #include "unicode.h" JS.Aug2010 reduce dependencies */
 
 #define pixel_at(pic, xx, yy)           (pic).p[(xx)+((yy)*((pic).x))]
 #define pixel_atp(pic, xx, yy)          (pic)->p[(xx)+((yy)*((pic)->x))]
