@@ -1,6 +1,6 @@
 /*
 This is a Optical-Character-Recognition program
-Copyright (C) 2000  Joerg Schulenburg
+Copyright (C) 2000-2006  Joerg Schulenburg
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -484,7 +484,7 @@ void print_pixel_env(FILE * out, pix * p, int x, int y) {
  * result depends on n_run, if n_run>0 filter are used
  * Returns: pixel-color (without marks)
  */
-int pixel(pix *p, int x, int y){
+int getpixel(pix *p, int x, int y){
   if ( x < 0 || y < 0 || x >= p->x || y >= p->y ) 
     return 255 & ~7;
 
