@@ -21,7 +21,8 @@ struct pixmap {
  };
 typedef struct pixmap pix;
 
-void readpgm(char *name, pix *p, int vvv);
+/* return 1 on multiple images (holding file open), 0 else */
+int readpgm(char *name, pix *p, int vvv);
 
 /* write pgm-map to pnm-file */
 int writepgm(char *nam, pix *p);
