@@ -1,6 +1,6 @@
 /*
 This is a Optical-Character-Recognition program
-Copyright (C) 2000-2009 Joerg Schulenburg
+Copyright (C) 2000-2010 Joerg Schulenburg
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -24,6 +24,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include "pgm2asc.h"
 #include "gocr.h"
 #include "progress.h"
+#include "unicode_defs.h" /* UNKNOWN + PICTURE */
 
 /* measure mean thickness as an criteria for big chars */
 int mean_thickness( struct box *box2 ){
@@ -84,10 +85,11 @@ int remove_dust( job_t *job ){
     /* maximum allowed dustsize (min=4*7 ca. 32)
      *  does not work for background pattern!
      */
-    job->cfg.dust_size = (  ( sX/nC ) * ( sY/nC ) + 16) / 32;
+    job->cfg.dust_size = (  ( sX/nC ) * ( sY/nC ) + 16) / 32; // maximum
+    if (sY/nC<10) job->cfg.dust_size=1; // 2010-09-24 6x9 gocr0801_bad5_FP 
     if (vvv) fprintf(stderr, "# remove.c remove_dust(): ");
     if (vvv) fprintf(stderr, "\n# dust size detection, vol num"
-      " #obj=%d maxDust=%d mpixel= %3d mxy= %2d %2d",
+      " obj=%d maxDust=%d mpixel= %3d mxy= %2d %2d",
       nC, job->cfg.dust_size, sP/nC, sX/nC, sY/nC);
     /* we assume that for random dust applies histo[i+1]<histo[i] */
     for (i=1;i+3<HISTSIZE;i++){
@@ -109,6 +111,7 @@ int remove_dust( job_t *job ){
       }
     }
     job->cfg.dust_size=i-1;
+    // 
     /* what is the statistic of random dust? 
      *    if we have p pixels on a x*y image we should have
      *    (p/(x*y))^1 * (x*y) = p         singlets     
