@@ -1,6 +1,6 @@
 /*
 This is a Optical-Character-Recognition program
-Copyright (C) 2000-2006  Joerg Schulenburg
+Copyright (C) 2000-2010  Joerg Schulenburg
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -19,7 +19,8 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  see README for EMAIL-address
  */
  
-#include "unicode.h"
+#include "unicode_defs.h" /* unicode table */
+#include "unicode.h"      /* convert functions and formats */
 #include <stdio.h>
 
 /* FIXME jb global */
@@ -52,7 +53,7 @@ wchar_t compose(wchar_t main, wchar_t modifier) {
     case SPACE:
 	return      (wchar_t)main;
 
-    case APOSTROPHE: /* do NOT USE this. It's here for compatibility only. 
+    case APOSTROPHE: /* do NOT USE this. It's here for compatibility only.
 			    Use ACUTE_ACCENT instead. */
       fprintf( stderr, "COMPOSE: got APOSTROPHE instead of ACUTE_ACCENT");
 
@@ -60,20 +61,20 @@ wchar_t compose(wchar_t main, wchar_t modifier) {
       switch (main) {
 	case 'a':	    return LATIN_SMALL_LETTER_A_WITH_ACUTE;
 	case 'A':	    return LATIN_CAPITAL_LETTER_A_WITH_ACUTE;
-        case LATIN_SMALL_LETTER_AE:   return LATIN_SMALL_LETTER_AE_WITH_ACUTE;
-        case LATIN_CAPITAL_LETTER_AE: return LATIN_CAPITAL_LETTER_AE_WITH_ACUTE;
+	case LATIN_SMALL_LETTER_AE:   return LATIN_SMALL_LETTER_AE_WITH_ACUTE;
+	case LATIN_CAPITAL_LETTER_AE: return LATIN_CAPITAL_LETTER_AE_WITH_ACUTE;
 	case 'c':	    return LATIN_SMALL_LETTER_C_WITH_ACUTE;
 	case 'C':	    return LATIN_CAPITAL_LETTER_C_WITH_ACUTE;
 	case 'e':	    return LATIN_SMALL_LETTER_E_WITH_ACUTE;
 	case 'E':	    return LATIN_CAPITAL_LETTER_E_WITH_ACUTE;
-        case 'g':           return LATIN_SMALL_LETTER_G_WITH_ACUTE;
-        case 'G':           return LATIN_CAPITAL_LETTER_G_WITH_ACUTE;
+	case 'g':           return LATIN_SMALL_LETTER_G_WITH_ACUTE;
+	case 'G':           return LATIN_CAPITAL_LETTER_G_WITH_ACUTE;
 	case 'i':	    return LATIN_SMALL_LETTER_I_WITH_ACUTE;
 	case 'I':	    return LATIN_CAPITAL_LETTER_I_WITH_ACUTE;
-        case 'l':           return LATIN_SMALL_LETTER_L_WITH_ACUTE;
-        case 'L':           return LATIN_CAPITAL_LETTER_L_WITH_ACUTE;
-        case 'n':           return LATIN_SMALL_LETTER_N_WITH_ACUTE;
-        case 'N':           return LATIN_CAPITAL_LETTER_N_WITH_ACUTE;
+	case 'l':           return LATIN_SMALL_LETTER_L_WITH_ACUTE;
+	case 'L':           return LATIN_CAPITAL_LETTER_L_WITH_ACUTE;
+	case 'n':           return LATIN_SMALL_LETTER_N_WITH_ACUTE;
+	case 'N':           return LATIN_CAPITAL_LETTER_N_WITH_ACUTE;
 	case 'o':	    return LATIN_SMALL_LETTER_O_WITH_ACUTE;
 	case 'O':	    return LATIN_CAPITAL_LETTER_O_WITH_ACUTE;
 	case '0':	    return LATIN_CAPITAL_LETTER_O_WITH_ACUTE;
@@ -255,6 +256,8 @@ wchar_t compose(wchar_t main, wchar_t modifier) {
 	case 'Y':	    return LATIN_CAPITAL_LETTER_Y_WITH_MACRON;
 	case LATIN_SMALL_LETTER_AE:   return LATIN_SMALL_LETTER_AE_WITH_MACRON;
 	case LATIN_CAPITAL_LETTER_AE: return LATIN_CAPITAL_LETTER_AE_WITH_MACRON;
+	case '=':	    return IDENTICAL_TO;
+	case '-':	    return '=';
 	case ' ':	    return MODIFIER_LETTER_MACRON;
         default:
           if(warn)fprintf( stderr, " COMPOSE: MACRON+%04x not defined\n",(int)main);
@@ -490,7 +493,7 @@ const char *decode(wchar_t c, FORMAT type) {
 	default:
 	  /* snprintf seems to be no standard, so I use insecure sprintf */
 	  sprintf(buf,"\\code(%04x)",(unsigned)c);
-	  return buf;  // UNDEFINED;
+	  return buf;  /* UNDEFINED; */
       }
       break;
     case TeX:
@@ -934,6 +937,9 @@ const char *decode(wchar_t c, FORMAT type) {
 	case LATIN_SMALL_LIGATURE_LONG_S_T:
 	case LATIN_SMALL_LIGATURE_ST:
 	  return (const char *)"st";
+        /* math */
+        case UNICODE_INFINITY:
+          return (const char *)"\\infty"; 
 	/* reserved */
 	case 0:
 	  return (const char *)"";
@@ -944,7 +950,7 @@ const char *decode(wchar_t c, FORMAT type) {
 	default:
 	  /* snprintf seems to be no standard, so I use insecure sprintf */
 	  sprintf(buf,"\\symbol{%u}",(unsigned)c);
-	  return buf;  // UNDEFINED;
+	  return buf;  /* UNDEFINED; */
 	}
     case HTML:
       if ( c >= SPACE && c <= TILDE ) { /* ASCII */
@@ -968,9 +974,9 @@ const char *decode(wchar_t c, FORMAT type) {
 	case PICTURE:
 	  return (const char *)"<!--PICTURE-->";
         case UNKNOWN:
-          return (const char *)"_"; // better use colored symbol?
+          return (const char *)"_"; /* better use colored symbol? */
         case LINE_FEED:
-          return (const char *)"<br />";  // \n handled somwhere else?
+          return (const char *)"<br />";  /* \n handled somwhere else? */
 	case FORM_FEED:
 	case CARRIAGE_RETURN:
 	  return (const char *)"<br />";
@@ -1194,9 +1200,9 @@ const char *decode(wchar_t c, FORMAT type) {
 	  return (const char *)"";
 	default:
 	  sprintf(buf,"&#%u;",(unsigned)c);
-	  return buf;  // undefined
+	  return buf;  /* undefined */
       }
-      break;
+      /* break; unreachable code */
     case XML:   /* only 5 &xxx;-ENTITIES ar defined by default */
       if ( c >= SPACE && c <= TILDE ) { /* ASCII */
         switch (c) {
@@ -1218,8 +1224,8 @@ const char *decode(wchar_t c, FORMAT type) {
 	case PICTURE:
 	  return (const char *)"(PICTURE)";
         case UNKNOWN:
-          return (const char *)"_"; // better use colored symbol?
-        case LINE_FEED:             // \n handled somwhere else?
+          return (const char *)"_"; /* better use colored symbol? */
+        case LINE_FEED:             /* \n handled somwhere else? */
 	case FORM_FEED:
 	case CARRIAGE_RETURN:
 	  return (const char *)"<br />";
@@ -1229,16 +1235,16 @@ const char *decode(wchar_t c, FORMAT type) {
 	  return (const char *)"";
 	default:
 	  sprintf(buf,"&#x%03x;",(unsigned)c);
-	  return buf;  // undefined
+	  return buf;  /* undefined */
       }
-      break;
+      /* break; unreachable code */
     case SGML:
       switch (c) {
 	default:
 	  sprintf(buf,"&#%u;",(unsigned)c);
-	  return buf;  // UNDEFINED
+	  return buf;  /* UNDEFINED */
       }
-      break;
+      /* break; unreachable code */
     case ASCII: /* mainly used for debugging */
       if ( c=='\n' || (c>= 0x20 && c <= 0x7F) ) {
         buf[0] = (char)c;
@@ -1255,54 +1261,55 @@ const char *decode(wchar_t c, FORMAT type) {
 	  /* snprintf seems to be no standard, so I use insecure sprintf */
 	  if ((unsigned)c>255) sprintf(buf,"(0x%04x)",(unsigned)c);
 	  else                 sprintf(buf,"(0x%02x)",(unsigned)c);
-	  return buf;  // UNDEFINED;
+	  return buf;  /* UNDEFINED; */
       }
-      break;
+      /* break; unreachable code */
     default: /* use UTF8 as default, test with xterm -u8 */
       /* extra */
       if ( c == UNKNOWN )  return (const char *)"_";
       if ( c == PICTURE )  return (const char *)"_"; /* Due to Mobile OCR */
-      if ( c <= 0x0000007F ) {      /* UTF8 == 7bit ASCII */
+      if ( c <= (wchar_t)0x0000007F ) {  /* UTF8 == 7bit ASCII */
         buf[0] = (char)c;
         return buf;
       }
       if ( c <= (wchar_t)0x000007FF ) {  /* UTF8 == 11bit */
-        buf[0] = (char)(0xc0|(c>> 6 & 0x1f)); /* 110xxxxx */
-        buf[1] = (char)(0x80|(c     & 0x3f)); /* 10xxxxxx */
+        buf[0] = (char)(0xc0|((c>> 6) & 0x1f)); /* 110xxxxx */
+        buf[1] = (char)(0x80|( c      & 0x3f)); /* 10xxxxxx */
         buf[2] = (char)0; /* terminate string */
         return buf;
       }
+      /* wchar_t is 16bit for Borland-C !? Jan07 */
       if ( c <= (wchar_t)0x0000FFFF ) {  /* UTF8 == 16bit */
-        buf[0] = (char)(0xe0|(c>>12 & 0x0f)); /* 1110xxxx */
-        buf[1] = (char)(0x80|(c>> 6 & 0x3f)); /* 10xxxxxx */
-        buf[2] = (char)(0x80|(c     & 0x3f)); /* 10xxxxxx */
+        buf[0] = (char)(0xe0|((c>>12) & 0x0f)); /* 1110xxxx */
+        buf[1] = (char)(0x80|((c>> 6) & 0x3f)); /* 10xxxxxx */
+        buf[2] = (char)(0x80|( c      & 0x3f)); /* 10xxxxxx */
         buf[3] = (char)0; /* terminate string */
         return buf;
       }
       if ( c <= (wchar_t)0x001FFFFF ) {  /* UTF8 == 21bit */
-        buf[0] = (char)(0xf0|(c>>18 & 0x07)); /* 11110xxx */
-        buf[1] = (char)(0x80|(c>>12 & 0x3f)); /* 10xxxxxx */
-        buf[2] = (char)(0x80|(c>> 6 & 0x3f)); /* 10xxxxxx */
-        buf[3] = (char)(0x80|(c     & 0x3f)); /* 10xxxxxx */
+        buf[0] = (char)(0xf0|((c>>18) & 0x07)); /* 11110xxx */
+        buf[1] = (char)(0x80|((c>>12) & 0x3f)); /* 10xxxxxx */
+        buf[2] = (char)(0x80|((c>> 6) & 0x3f)); /* 10xxxxxx */
+        buf[3] = (char)(0x80|( c      & 0x3f)); /* 10xxxxxx */
         buf[4] = (char)0; /* terminate string */
         return buf;
       }
       if ( c <= (wchar_t)0x03FFFFFF ) {  /* UTF8 == 26bit */
-        buf[0] = (char)(0xf8|(c>>24 & 0x03)); /* 111110xx */
-        buf[1] = (char)(0x80|(c>>18 & 0x3f)); /* 10xxxxxx */
-        buf[2] = (char)(0x80|(c>>12 & 0x3f)); /* 10xxxxxx */
-        buf[3] = (char)(0x80|(c>> 6 & 0x3f)); /* 10xxxxxx */
-        buf[4] = (char)(0x80|(c     & 0x3f)); /* 10xxxxxx */
+        buf[0] = (char)(0xf8|((c>>24) & 0x03)); /* 111110xx */
+        buf[1] = (char)(0x80|((c>>18) & 0x3f)); /* 10xxxxxx */
+        buf[2] = (char)(0x80|((c>>12) & 0x3f)); /* 10xxxxxx */
+        buf[3] = (char)(0x80|((c>> 6) & 0x3f)); /* 10xxxxxx */
+        buf[4] = (char)(0x80|( c      & 0x3f)); /* 10xxxxxx */
         buf[5] = (char)0; /* terminate string */
         return buf;
       }
       if ( c <= (wchar_t)0x7FFFFFFF ) {  /* UTF8 == 31bit */
-        buf[0] = (char)(0xfc|(c>>30 & 0x01)); /* 1111110x */
-        buf[1] = (char)(0x80|(c>>24 & 0x3f)); /* 10xxxxxx */
-        buf[2] = (char)(0x80|(c>>18 & 0x3f)); /* 10xxxxxx */
-        buf[3] = (char)(0x80|(c>>12 & 0x3f)); /* 10xxxxxx */
-        buf[4] = (char)(0x80|(c>> 6 & 0x3f)); /* 10xxxxxx */
-        buf[5] = (char)(0x80|(c     & 0x3f)); /* 10xxxxxx */
+        buf[0] = (char)(0xfc|((c>>30) & 0x01)); /* 1111110x */
+        buf[1] = (char)(0x80|((c>>24) & 0x3f)); /* 10xxxxxx */
+        buf[2] = (char)(0x80|((c>>18) & 0x3f)); /* 10xxxxxx */
+        buf[3] = (char)(0x80|((c>>12) & 0x3f)); /* 10xxxxxx */
+        buf[4] = (char)(0x80|((c>> 6) & 0x3f)); /* 10xxxxxx */
+        buf[5] = (char)(0x80|( c      & 0x3f)); /* 10xxxxxx */
         buf[6] = (char)0; /* terminate string */
         return buf;
       }
